@@ -54,8 +54,7 @@ class Gateway():
             Discover all devices registered on the usb-commeo        
         """
         self._Machine = Machine(self, self._machineId)
-        self.devices = self._Machine.get_zones()
-        print(str(self.devices))
+        self.devices = list(filter(lambda z: z.zoneId != 0, self._Machine.get_zones()))
 
     def init_polling(self):
         self._poll = True
@@ -96,4 +95,6 @@ class Gateway():
 
 if __name__ == '__main__':
     gateway = Gateway('modbus.local', 5020, 1)
-    gateway.init_polling()
+    a = gateway._Machine
+    #gateway.init_polling()
+
